@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 4.2.1, released 7 May 2018.
+# Version 4.3.0, released 25 Nov 2018.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -46,6 +46,7 @@ use Cwd;
 use Digest::MD5;
 use Config;
 use Encode qw/from_to encode_utf8/;
+use POSIX qw/_exit/;
 
 use BackupPC::Storage;
 use BackupPC::XS;
@@ -97,7 +98,7 @@ sub new
 
     my $bpc = bless {
 	%$paths,
-        Version => '4.2.1',
+        Version => '4.3.0',
     }, $class;
 
     $bpc->{storage} = BackupPC::Storage->new($paths);
@@ -878,16 +879,17 @@ sub CheckHostAlive
 
 sub CheckFileSystemUsage
 {
-    my($bpc) = @_;
+    my($bpc, $inode) = @_;
     my($topDir) = $bpc->{TopDir};
     my($s, $dfCmd);
+    my $cmd = $inode ? "DfInodeUsageCmd" : "DfCmd";
 
-    return 0 if ( $bpc->{Conf}{DfCmd} eq "" );
+    return 0 if ( $bpc->{Conf}{$cmd} eq "" );
     my $args = {
 	dfPath   => $bpc->{Conf}{DfPath},
 	topDir   => $bpc->{TopDir},
     };
-    $dfCmd = $bpc->cmdVarSubstitute($bpc->{Conf}{DfCmd}, $args);
+    $dfCmd = $bpc->cmdVarSubstitute($bpc->{Conf}{$cmd}, $args);
     $s = $bpc->cmdSystemOrEval($dfCmd, undef, $args);
     return 0 if ( $? || $s !~ /(\d+)%/s );
     return $1;
@@ -1157,7 +1159,7 @@ sub cmdExecOrEval
 			if ( $bpc->{verbose} );
         eval($cmd);
         print(STDERR "Perl code fragment for exec shouldn't return!!\n");
-        exit(1);
+        POSIX::_exit(1);
     } else {
         $cmd = [split(/\s+/, $cmd)] if ( ref($cmd) ne "ARRAY" );
 	print(STDERR "cmdExecOrEval: about to exec ",
@@ -1170,7 +1172,7 @@ sub cmdExecOrEval
 	#
         exec { $cmd->[0] } @$cmd;
         print(STDERR "Exec failed for @$cmd\n");
-        exit(1);
+        POSIX::_exit(1);
     }
 }
 
@@ -1234,7 +1236,7 @@ sub cmdSystemOrEvalLong
 	    #
 	    exec { $cmd->[0] } @$cmd;
             print(STDERR "Exec of @$cmd failed\n");
-            exit(1);
+            POSIX::_exit(1);
 	}
 
 	#
